FileSaverWeb class

A web implementation of the FileSaver plugin.

Constructors

FileSaverWeb()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handleMethodCall(MethodCall call) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

canSaveStream bool
no setter

Static Methods

downloadFile(FileModel fileModel) Future<bool>
registerWith(Registrar registrar) → void
saveLinkStream({required String name, required LinkDetails link, required bool includeCredentials}) Future<bool>
saveStream({required String name, required Stream<List<int>> stream}) Future<bool>